/******************************** LICENSE ********************************


 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
 
 Licensed under the Apache License, Version 2.0 (the "License"); 
 you may not use this file except in compliance with the License. 
 You may obtain a copy of the License at 
 
 	http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software 
 distributed under the License is distributed on an "AS IS" BASIS, 
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 See the License for the specific language governing permissions and 
 limitations under the License.


 ******************************** LICENSE ********************************/

/*!
    \file SciMethods.cc
    \brief Definition of SciMethods.
    \author Graphics Section, ECMWF

    Started: September 2011
*/

#include <math.h>

#include "SciMethods.h"

namespace magics 
{
  
//float cp=1005;
//float L=2500000;
//float Rd=287.04;
const double KAPPA=0.285611; //Rd/cp
//float KK=273.15;
//const double R=8.3144621;

/*! Computes the distance on Earth in km */
double geoDistanceInKm(double fi1,double la1,double fi2,double la2)
{ 
	double rfi1=RAD(fi1);
	double rla1=RAD(la1);
	double rfi2=RAD(fi2);
	double rla2=RAD(la2);

   	if(rla1 != rla2)
     	{
       		double d=sin(rfi1)*sin(rfi2)+cos(rfi1)*cos(rfi2)*cos(fabs(rla1-rla2));
       		return acos(d)*EarthRadiusInKm;
     	}
	else
	{  
   	      	return fabs(rfi1-rfi2)*EarthRadiusInKm;

	}

}

/*! 
  \brief computes potential temperature

   This method computes the potential temperature for a given
   temperature and pressure.
   
   \param t temperature in K
   \param p pressure in Pa 
   \return potential temperature in K
 */
double theta(double t, double p)
{
	return t*pow(100000./p,KAPPA); 
} 

/*! 
  \brief computes temperature from potential temperature

   This method computes the temperature for a given 
   potential temperature and pressure.
   
   \param th potential temperature in K
   \param p pressure in Pa   
   \return temperature in K
   
*/
double temperatureFromTheta(double th, double p)
{	
   	return th*pow(p/100000.,KAPPA); 
}

/*! 
  \brief computes pressure from potential temperature

   This method computes the pressure for a given 
   potential temperature and temperature.
   
   \param th potential temperature in K
   \param t temperature in K 
   \return pressure in Pa   
*/
double pressureFromTheta(double th, double t)
{	
   	return 100000.*pow(t/th,1./KAPPA); 
}

} //end namespace